import { color } from '@web3uikit/styles';
import { CardProps } from './types';
import { Checkmark, HelpCircle } from '@web3uikit/icons';
import { Tooltip } from '../Tooltip';
import styles from './Card.styles';
import { Typography } from '../Typography';

const { AbsoluteIconStyled, DivStyled, FooterStyled, HeaderStyled } = styles;

const Card: React.FC<CardProps> = ({
    children,
    cursorType = 'pointer',
    description,
    id,
    isDisabled = false,
    isSelected,
    onClick,
    setIsSelected,
    title,
    tooltipMove,
    tooltipMoveBody,
    tooltipText,
    ...props
}: CardProps) => {
    return (
        <DivStyled
            aria-label={isSelected ? 'card not selected' : 'card selected'}
            data-testid="test-card"
            id={id}
            onClick={() => {
                if (isDisabled) return;
                onClick && onClick();
                if (!setIsSelected) return;
                setIsSelected(!isSelected);
            }}
            role="button"
            isSelected={isSelected}
            isDisabled={isDisabled}
            cursorType={cursorType}
            {...props}
        >
            <HeaderStyled data-testid={'test-card-header'}>
                {isSelected && (
                    <AbsoluteIconStyled position="topL">
                        <Checkmark
                            data-testid="test-card-icon-check"
                            title="checkmark icon"
                            titleId="card checkmark icon"
                            fill={color.green}
                            fontSize={24}
                        />
                    </AbsoluteIconStyled>
                )}
                {!isDisabled && tooltipText && (
                    <AbsoluteIconStyled position="topR">
                        <Tooltip
                            children={[
                                <HelpCircle
                                    fill={color.blue}
                                    fontSize={22}
                                    key="tip-card"
                                    title="help circle icon"
                                    titleId="card help circle icon"
                                />,
                            ]}
                            content={tooltipText}
                            move={tooltipMove}
                            moveBody={tooltipMoveBody}
                            position={'bottom'}
                        />
                    </AbsoluteIconStyled>
                )}
            </HeaderStyled>
            <div>{children}</div>
            {(title || description) && (
                <FooterStyled>
                    {title && (
                        <Typography
                            color={color.blue}
                            data-testid="test-card-title"
                            variant="subtitle2"
                        >
                            {title}
                        </Typography>
                    )}
                    {description && (
                        <Typography
                            color={color.blue}
                            data-testid="test-card-description"
                            variant="caption14"
                        >
                            {description}
                        </Typography>
                    )}
                </FooterStyled>
            )}
        </DivStyled>
    );
};
export default Card;
